summaryrefslogtreecommitdiff
path: root/src/arch/arm/v7/operands/rotation.h
diff options
context:
space:
mode:
authorCyrille Bagard <nocbos@gmail.com>2017-05-21 16:48:11 (GMT)
committerCyrille Bagard <nocbos@gmail.com>2017-05-21 16:48:11 (GMT)
commitacd355c4c5ae25fb9cac64b8dc17407a2bcc979b (patch)
treed5b43201049116cd9734ff554e61ed8a7e0084cc /src/arch/arm/v7/operands/rotation.h
parent4691a434a34a19317156a761967f719e408b73bb (diff)
Refined the whole share system for operands.
Diffstat (limited to 'src/arch/arm/v7/operands/rotation.h')
-rw-r--r--src/arch/arm/v7/operands/rotation.h26
1 files changed, 21 insertions, 5 deletions
diff --git a/src/arch/arm/v7/operands/rotation.h b/src/arch/arm/v7/operands/rotation.h
index e42b219..399baf4 100644
--- a/src/arch/arm/v7/operands/rotation.h
+++ b/src/arch/arm/v7/operands/rotation.h
@@ -40,22 +40,38 @@
#define G_ARMV7_ROTATION_OPERAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_ARMV7_ROTATION_OPERAND, GArmV7RotationOperandClass))
/* Définition d'un opérande visant une liste d'opérandes Dalvik (instance) */
typedef struct _GArmV7RotationOperand GArmV7RotationOperand;
/* Définition d'un opérande visant une liste d'opérandes Dalvik (classe) */
typedef struct _GArmV7RotationOperandClass GArmV7RotationOperandClass;
/* Indique le type défini par la GLib pour une liste d'arguments Dalvik. */
GType g_armv7_rotation_operand_get_type(void);
/* Crée un réceptacle pour opérandes Dalvik servant d'arguments. */
GArchOperand *g_armv7_rotation_operand_new(GArchOperand *);
/* Founit la valeur utilisée pour un décallage. */
GArchOperand *g_armv7_rotation_operand_get_value(const GArmV7RotationOperand *);
+/* -------------------------- PARTAGES DE CONTENUS UNIQUES -------------------------- */
+
+
+/* Met en place les mécanismes de partage des rotation ARMv7. */
+bool init_armv7_rotation_operand_sharing(void);
+
+/* Imprime des statistiques quant aux partages dans l'archi. */
+#ifdef DEBUG_DUMP_STATS
+void dump_armv7_rotation_operand_share_stats(void);
+#endif
+
+/* Supprime les mécanismes de partage des opérandes de rotation. */
+void exit_armv7_rotation_operand_sharing(void);
+
+
+
#endif /* _ARCH_ARM_V7_OPERANDS_ROTATION_H */
@@ -40,22 +40,38 @@
#define G_ARMV7_ROTATION_OPERAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_ARMV7_ROTATION_OPERAND, GArmV7RotationOperandClass))
-/* Définition d'un opérande visant une liste d'opérandes Dalvik (instance) */
+/* Définition d'un opérande visant une opérande de rotation ARMv7 (instance) */
typedef struct _GArmV7RotationOperand GArmV7RotationOperand;
@@ -40,22 +40,38 @@
typedef struct _GArmV7RotationOperand GArmV7RotationOperand;
-/* Définition d'un opérande visant une liste d'opérandes Dalvik (classe) */
+/* Définition d'un opérande visant une opérande de rotation ARMv7 (classe) */
typedef struct _GArmV7RotationOperandClass GArmV7RotationOperandClass;
@@ -40,22 +40,38 @@
typedef struct _GArmV7RotationOperandClass GArmV7RotationOperandClass;
-/* Indique le type défini par la GLib pour une liste d'arguments Dalvik. */
+/* Indique le type défini par la GLib pour une opérande de rotation ARMv7. */
GType g_armv7_rotation_operand_get_type(void);
@@ -40,22 +40,38 @@
GType g_armv7_rotation_operand_get_type(void);
-/* Crée un réceptacle pour opérandes Dalvik servant d'arguments. */
+/* Crée un réceptacle pour opérandes de rotation ARMv7. */
GArchOperand *g_armv7_rotation_operand_new(GArchOperand *);
@@ -40,22 +40,38 @@
GArchOperand *g_armv7_rotation_operand_new(GArchOperand *);
-/* Founit la valeur utilisée pour un décallage. */
+/* Founit la valeur utilisée pour une rotation. */
GArchOperand *g_armv7_rotation_operand_get_value(const GArmV7RotationOperand *);